@@ -69,9 +69,9 @@ def create_parser():
     return parser
 
 
-def run():
+def run(raw_args=None):
     parser = create_parser()
-    args = parser.parse_args()
+    args = parser.parse_args(raw_args)
 
     level = logging.DEBUG if args.verbose else logging.INFO
     logging.basicConfig(
